{% load menu_tags %}
{% if menu_items %}
    <nav class="nav-section" role="navigation">
        {% if show_section_root and section_root %}
            <a href="{{ section_root.href }}" class="{{ section_root.active_class }} section_root">{{ section_root.text }}</a>
        {% endif %}
        <ul>
            {% for item in menu_items %}
                <li class="{{ item.active_class }}">
                    <a href="{{ item.href }}">{{ item.text }}</a>
                    {% if item.has_children_in_menu %}
                         {% children_menu item stop_at_this_level=False %}
                    {% endif %}
                </li>
            {% endfor %}
        </ul>
    </nav>
{% endif %}
